@@ -1,4 +1,6 @@
-from django.contrib.auth.models import AbstractBaseUser, BaseUserManager, PermissionsMixin
+""" User models."""
+from django.contrib.auth.models import (
+    AbstractBaseUser, BaseUserManager, PermissionsMixin)
 from django.core.mail import send_mail
 from django.db import models
 from django.utils import timezone
@@ -7,10 +9,19 @@ from django.utils.translation import ugettext_lazy as _
 
 class EmailUserManager(BaseUserManager):
 
+    """ Custom manager for EmailUser."""
+
     def _create_user(self, email, password,
                      is_staff, is_superuser, **extra_fields):
-        """
-        Creates and saves an EmailUser with the given email and password.
+        """ Create and save an EmailUser with the given email and password.
+
+        :param str email: user email
+        :param str password: user password
+        :param bool is_staff: whether user staff or not
+        :param bool is_superuser: whether user admin or not
+        :return custom_user.models.EmailUser user: user
+        :raise ValueError: email is not set
+
         """
         now = timezone.now()
         if not email:
@@ -25,20 +36,35 @@ class EmailUserManager(BaseUserManager):
         return user
 
     def create_user(self, email, password=None, **extra_fields):
+        """ Create and save an EmailUser with the given email and password.
+
+        :param str email: user email
+        :param str password: user password
+        :return custom_user.models.EmailUser user: regular user
+
+        """
         is_staff = extra_fields.pop("is_staff", False)
         return self._create_user(email, password, is_staff, False,
                                  **extra_fields)
 
     def create_superuser(self, email, password, **extra_fields):
+        """ Create and save an EmailUser with the given email and password.
+
+        :param str email: user email
+        :param str password: user password
+        :return custom_user.models.EmailUser user: admin user
+
+        """
         return self._create_user(email, password, True, True,
                                  **extra_fields)
 
 
 class AbstractEmailUser(AbstractBaseUser, PermissionsMixin):
-    """
-    Abstract User with the same behaviour as Django's default User but
-    without a username field. Uses email as the USERNAME_FIELD for
-    authentication.
+
+    """ Abstract User with the same behaviour as Django's default User.
+
+    AbstractEmailUser does not have username field. Uses email as the
+    USERNAME_FIELD for authentication.
 
     Use this if you need to extend EmailUser.
 
@@ -48,15 +74,17 @@ class AbstractEmailUser(AbstractBaseUser, PermissionsMixin):
         * password
         * last_login
         * is_superuser
+
     """
+
     email = models.EmailField(_('email address'), max_length=255,
                               unique=True, db_index=True)
-    is_staff = models.BooleanField(_('staff status'), default=False,
-        help_text=_('Designates whether the user can log into this admin '
-                    'site.'))
-    is_active = models.BooleanField(_('active'), default=True,
-        help_text=_('Designates whether this user should be treated as '
-                    'active. Unselect this instead of deleting accounts.'))
+    is_staff = models.BooleanField(
+        _('staff status'), default=False, help_text=_(
+            'Designates whether the user can log into this admin site.'))
+    is_active = models.BooleanField(_('active'), default=True, help_text=_(
+        'Designates whether this user should be treated as '
+        'active. Unselect this instead of deleting accounts.'))
     date_joined = models.DateTimeField(_('date joined'), default=timezone.now)
 
     objects = EmailUserManager()
@@ -70,29 +98,26 @@ class AbstractEmailUser(AbstractBaseUser, PermissionsMixin):
         abstract = True
 
     def get_full_name(self):
-        """
-        Returns the email.
-        """
+        """ Return the email."""
         return self.email
 
     def get_short_name(self):
-        """
-        Returns the email.
-        """
+        """ Return the email."""
         return self.email
 
-    def email_user(self, subject, message, from_email=None):
-        """
-        Sends an email to this User.
-        """
-        send_mail(subject, message, from_email, [self.email])
+    def email_user(self, subject, message, from_email=None, **kwargs):
+        """ Send an email to this User."""
+        send_mail(subject, message, from_email, [self.email], **kwargs)
 
 
 class EmailUser(AbstractEmailUser):
+
     """
     Concrete class of AbstractEmailUser.
 
     Use this if you don't need to extend EmailUser.
+
     """
+
     class Meta(AbstractEmailUser.Meta):
         swappable = 'AUTH_USER_MODEL'
